@@ -50,7 +50,14 @@ class Configuration(
         :param enable_resource_property_constraint: -
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(Configuration.__init__)
+            def stub(
+                scope: ros_cdk_core.Construct,
+                id: builtins.str,
+                props: typing.Union["ConfigurationProps", typing.Dict[str, typing.Any]],
+                enable_resource_property_constraint: typing.Optional[builtins.bool] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
             check_type(argname="argument props", value=props, expected_type=type_hints["props"])
@@ -115,7 +122,19 @@ class ConfigurationProps:
         :param type: Property type: Provisioning content format, optional values as follows: text, json, xml, yaml, text/html, properties.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(ConfigurationProps.__init__)
+            def stub(
+                *,
+                content: typing.Union[builtins.str, ros_cdk_core.IResolvable],
+                data_id: typing.Union[builtins.str, ros_cdk_core.IResolvable],
+                namespace_id: typing.Union[builtins.str, ros_cdk_core.IResolvable],
+                app_name: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
+                desc: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
+                group: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
+                tags: typing.Optional[builtins.str] = None,
+                type: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument content", value=content, expected_type=type_hints["content"])
             check_type(argname="argument data_id", value=data_id, expected_type=type_hints["data_id"])
             check_type(argname="argument namespace_id", value=namespace_id, expected_type=type_hints["namespace_id"])
@@ -242,7 +261,14 @@ class Namespace(
         :param enable_resource_property_constraint: -
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(Namespace.__init__)
+            def stub(
+                scope: ros_cdk_core.Construct,
+                id: builtins.str,
+                props: typing.Union["NamespaceProps", typing.Dict[str, typing.Any]],
+                enable_resource_property_constraint: typing.Optional[builtins.bool] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
             check_type(argname="argument props", value=props, expected_type=type_hints["props"])
@@ -278,7 +304,12 @@ class NamespaceProps:
         :param name: Property name: Namespace name.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(NamespaceProps.__init__)
+            def stub(
+                *,
+                name: typing.Union[builtins.str, ros_cdk_core.IResolvable],
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument name", value=name, expected_type=type_hints["name"])
         self._values: typing.Dict[str, typing.Any] = {
             "name": name,
@@ -325,7 +356,14 @@ class RosConfiguration(
         :param enable_resource_property_constraint: -
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(RosConfiguration.__init__)
+            def stub(
+                scope: ros_cdk_core.Construct,
+                id: builtins.str,
+                props: typing.Union["RosConfigurationProps", typing.Dict[str, typing.Any]],
+                enable_resource_property_constraint: builtins.bool,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
             check_type(argname="argument props", value=props, expected_type=type_hints["props"])
@@ -341,7 +379,9 @@ class RosConfiguration(
         :param props: -
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(RosConfiguration._render_properties)
+            def stub(props: typing.Mapping[builtins.str, typing.Any]) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument props", value=props, expected_type=type_hints["props"])
         return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "renderProperties", [props]))
 
@@ -394,7 +434,11 @@ class RosConfiguration(
         value: typing.Union[builtins.str, ros_cdk_core.IResolvable],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(RosConfiguration, "content").fset)
+            def stub(
+                value: typing.Union[builtins.str, ros_cdk_core.IResolvable],
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "content", value)
 
@@ -416,7 +460,11 @@ class RosConfiguration(
         value: typing.Union[builtins.str, ros_cdk_core.IResolvable],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(RosConfiguration, "data_id").fset)
+            def stub(
+                value: typing.Union[builtins.str, ros_cdk_core.IResolvable],
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "dataId", value)
 
@@ -428,7 +476,9 @@ class RosConfiguration(
     @enable_resource_property_constraint.setter
     def enable_resource_property_constraint(self, value: builtins.bool) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(RosConfiguration, "enable_resource_property_constraint").fset)
+            def stub(value: builtins.bool) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "enableResourcePropertyConstraint", value)
 
@@ -446,7 +496,11 @@ class RosConfiguration(
         value: typing.Union[builtins.str, ros_cdk_core.IResolvable],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(RosConfiguration, "namespace_id").fset)
+            def stub(
+                value: typing.Union[builtins.str, ros_cdk_core.IResolvable],
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "namespaceId", value)
 
@@ -466,7 +520,11 @@ class RosConfiguration(
         value: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(RosConfiguration, "app_name").fset)
+            def stub(
+                value: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]],
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "appName", value)
 
@@ -486,7 +544,11 @@ class RosConfiguration(
         value: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(RosConfiguration, "desc").fset)
+            def stub(
+                value: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]],
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "desc", value)
 
@@ -506,7 +568,11 @@ class RosConfiguration(
         value: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(RosConfiguration, "group").fset)
+            def stub(
+                value: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]],
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "group", value)
 
@@ -521,7 +587,9 @@ class RosConfiguration(
     @tags.setter
     def tags(self, value: typing.Optional[builtins.str]) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(RosConfiguration, "tags").fset)
+            def stub(value: typing.Optional[builtins.str]) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "tags", value)
 
@@ -544,7 +612,11 @@ class RosConfiguration(
         value: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(RosConfiguration, "type").fset)
+            def stub(
+                value: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]],
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "type", value)
 
@@ -588,7 +660,19 @@ class RosConfigurationProps:
         :param type: 
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(RosConfigurationProps.__init__)
+            def stub(
+                *,
+                content: typing.Union[builtins.str, ros_cdk_core.IResolvable],
+                data_id: typing.Union[builtins.str, ros_cdk_core.IResolvable],
+                namespace_id: typing.Union[builtins.str, ros_cdk_core.IResolvable],
+                app_name: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
+                desc: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
+                group: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
+                tags: typing.Optional[builtins.str] = None,
+                type: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument content", value=content, expected_type=type_hints["content"])
             check_type(argname="argument data_id", value=data_id, expected_type=type_hints["data_id"])
             check_type(argname="argument namespace_id", value=namespace_id, expected_type=type_hints["namespace_id"])
@@ -729,7 +813,14 @@ class RosNamespace(
         :param enable_resource_property_constraint: -
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(RosNamespace.__init__)
+            def stub(
+                scope: ros_cdk_core.Construct,
+                id: builtins.str,
+                props: typing.Union["RosNamespaceProps", typing.Dict[str, typing.Any]],
+                enable_resource_property_constraint: builtins.bool,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
             check_type(argname="argument props", value=props, expected_type=type_hints["props"])
@@ -745,7 +836,9 @@ class RosNamespace(
         :param props: -
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(RosNamespace._render_properties)
+            def stub(props: typing.Mapping[builtins.str, typing.Any]) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument props", value=props, expected_type=type_hints["props"])
         return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "renderProperties", [props]))
 
@@ -784,7 +877,9 @@ class RosNamespace(
     @enable_resource_property_constraint.setter
     def enable_resource_property_constraint(self, value: builtins.bool) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(RosNamespace, "enable_resource_property_constraint").fset)
+            def stub(value: builtins.bool) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "enableResourcePropertyConstraint", value)
 
@@ -799,7 +894,11 @@ class RosNamespace(
     @name.setter
     def name(self, value: typing.Union[builtins.str, ros_cdk_core.IResolvable]) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(RosNamespace, "name").fset)
+            def stub(
+                value: typing.Union[builtins.str, ros_cdk_core.IResolvable],
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "name", value)
 
@@ -820,7 +919,12 @@ class RosNamespaceProps:
         :param name: 
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(RosNamespaceProps.__init__)
+            def stub(
+                *,
+                name: typing.Union[builtins.str, ros_cdk_core.IResolvable],
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument name", value=name, expected_type=type_hints["name"])
         self._values: typing.Dict[str, typing.Any] = {
             "name": name,
